import weboob.capabilities.bank as OLD

# can't import *, __all__ is incomplete...
for attr in dir(OLD):
    globals()[attr] = getattr(OLD, attr)

try:
    __all__ = OLD.__all__
except AttributeError:
    pass


class TransferStatus(Enum):
    UNKNOWN = 'unknown'

    SCHEDULED = 'scheduled'
    """Transfer to be executed later"""

    DONE = 'done'
    """Transfer was executed"""

    CANCELLED = 'cancelled'
    """Transfer was cancelled by the bank or by the user"""


class TransferFrequency(Enum):
    UNKNOWN = 'unknown'
    WEEKLY = 'weekly'
    MONTHLY = 'monthly'
    BIMONTHLY = 'bimonthly'
    QUARTERLY = 'quarterly'
    BIANNUAL = 'biannual'
    YEARLY = 'yearly'


class TransferDateType(Enum):
    FIRST_OPEN_DAY = 'first_open_day'
    """Transfer to execute when possible (accounting opening days)"""

    INSTANT = 'instant'
    """Transfer to execute immediately (not accounting opening days)"""

    DEFERRED = 'deferred'
    """Transfer to execute on a chosen date"""

    PERIODIC = 'periodic'
    """Transfer to execute periodically"""


Transfer._fields['creation_date'] = DateField('Creation date of transfer')
Transfer._fields['status'] = EnumField('Transfer status', TransferStatus)
Transfer._fields['date_type'] = EnumField('Transfer execution date type', TransferDateType)

Transfer._fields['frequency'] = EnumField('Frequency of periodic transfer', TransferFrequency)
Transfer._fields['first_due_date'] = DateField('Date of first transfer of periodic transfer')
Transfer._fields['last_due_date'] = DateField('Date of last transfer of periodic transfer')
Transfer._fields['cancelled_exception'] = Field('Transfer cancelled reason', TransferError)

Recipient._fields['origin_account_iban'] = StringField('Account iban which recipient belong to')


class EmitterNumberType(Enum):
    UNKNOWN = 'unknown'
    IBAN = 'iban'
    BBAN = 'bban'


class Emitter(BaseAccount):
    """
    Transfer emitter account.
    """
    number_type = EnumField('Account number type', EmitterNumberType, default=EmitterNumberType.UNKNOWN)
    number = StringField('Account number value')
    balance = DecimalField('Balance of emitter account')


class TransferCancelledByUser(TransferError):
    """The transfer is cancelled by the emitter or an authorized user"""

    code = 'cancelledByUser'


CapTransfer = CapBankTransfer

del OLD
