import weboob.capabilities.bank as OLD

for attr in dir(OLD):
    globals()[attr] = getattr(OLD, attr)

try:
    __all__ = OLD.__all__
except AttributeError:
    pass


class PerVersion(Enum):
    PERIN = 'perin'  # "PER individuel", subscribed by the account holder
    PERCOL = 'percol'  # "PER collectif", subscribed by the employer for all employees
    PERCAT = 'percat'  # "PER catégoriel", subscribed by the employer for a category of employees (for example managers)


class PerProviderType(Enum):
    BANK = 'bank'
    INSURER = 'insurer'


class Per(Account):
    """
    Account type dedicated to PER retirement savings plans.
    """

    version = EnumField('Version of PER', PerVersion)
    provider_type = EnumField('Type of account provider', PerProviderType)


class MarketOrderType(Enum):
    UNKNOWN = 0
    MARKET = 1
    """Order executed at the current market price"""
    LIMIT = 2
    """Order executed with a maximum or minimum price limit"""
    TRIGGER = 3
    """Order executed when the price reaches a specific value"""


class MarketOrderDirection(Enum):
    UNKNOWN = 0
    BUY = 1
    SALE = 2


class MarketOrderPayment(Enum):
    UNKNOWN = 0
    CASH = 1
    DEFERRED = 2


class MarketOrder(BaseObject):
    """
    Market order
    """

    # Important: a Market Order always corresponds to one (and only one) investment
    label = StringField('Label of the market order')

    # MarketOrder values
    unitprice = DecimalField('Value of the stock at the moment of the market order')
    unitvalue = DecimalField('Current value of the stock associated with the market order')
    ordervalue = DecimalField('Limit value or trigger value, only relevant if the order type is LIMIT or TRIGGER')
    currency = StringField('Currency of the market order - not always the same as account currency')
    quantity = DecimalField('Quantity of stocks in the market order')
    amount = DecimalField('Total amount that has been bought or sold')

    # MarketOrder additional information
    order_type = EnumField('Type of market order', MarketOrderType, default=MarketOrderType.UNKNOWN)
    direction = EnumField('Direction of the market order (buy or sale)', MarketOrderDirection, default=MarketOrderDirection.UNKNOWN)
    payment_method = EnumField('Payment method of the market order', MarketOrderPayment, default=MarketOrderPayment.UNKNOWN)
    date = DateField('Creation date of the market order')
    validity_date = DateField('Validity date of the market order')
    execution_date = DateField('Execution date of the market order (only for market orders that are completed)')
    state = StringField('Current state of the market order (e.g. executed)')
    code = StringField('Identifier of the stock related to the order')
    stock_market = StringField('Stock market on which the order was executed')


del OLD
